==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETCycleNode.h <==
// public abstract class soot.dava.internal.SET.SETCycleNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 92d03241e310e374 soot_dava_internal_SET_SETCycleNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETControlFlowNode

#include "soot/dava/internal/SET/SETControlFlowNode.h"

#ifndef _JC_soot_dava_internal_SET_SETCycleNode_H_
#define _JC_soot_dava_internal_SET_SETCycleNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$sub_refs	_jc_soot_dava_internal_SET_SETCycleNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$refs	_jc_soot_dava_internal_SET_SETCycleNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$nonrefs	_jc_soot_dava_internal_SET_SETCycleNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$object	_jc_soot_dava_internal_SET_SETCycleNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETCycleNode$vmethods	_jc_soot_dava_internal_SET_SETCycleNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETCycleNode$vtable	_jc_soot_dava_internal_SET_SETCycleNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETCycleNode$vtype	_jc_soot_dava_internal_SET_SETCycleNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETCycleNode$method$_init$88b2f90f98cac172(_jc_env *, struct _jc_soot_dava_internal_SET_SETCycleNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *);

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETCycleNode$vmethods {
};

// Vtable
struct _jc_soot_dava_internal_SET_SETCycleNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETCycleNode$vmethods	soot_dava_internal_SET_SETCycleNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETCycleNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETCycleNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETCycleNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETCycleNode$refs {
    _jc_soot_dava_internal_SET_SETCycleNode$sub_refs	soot_dava_internal_SET_SETCycleNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETCycleNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs	soot_dava_internal_SET_SETCycleNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETCycleNode$object {
	_jc_soot_dava_internal_SET_SETCycleNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETCycleNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETCycleNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETCycleNode$vtype _jc_soot_dava_internal_SET_SETCycleNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETCycleNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETCycleNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETCycleNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETCycleNode.h <==
// public abstract class soot.dava.internal.SET.SETCycleNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 92d03241e310e374 soot_dava_internal_SET_SETCycleNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETControlFlowNode

#include "soot/dava/internal/SET/SETControlFlowNode.h"

#ifndef _JC_soot_dava_internal_SET_SETCycleNode_H_
#define _JC_soot_dava_internal_SET_SETCycleNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$sub_refs	_jc_soot_dava_internal_SET_SETCycleNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$refs	_jc_soot_dava_internal_SET_SETCycleNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$nonrefs	_jc_soot_dava_internal_SET_SETCycleNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETCycleNode$object	_jc_soot_dava_internal_SET_SETCycleNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETCycleNode$vmethods	_jc_soot_dava_internal_SET_SETCycleNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETCycleNode$vtable	_jc_soot_dava_internal_SET_SETCycleNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETCycleNode$vtype	_jc_soot_dava_internal_SET_SETCycleNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETCycleNode$method$_init$88b2f90f98cac172(_jc_env *, struct _jc_soot_dava_internal_SET_SETCycleNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETCycleNode$vmethods {
};

// Vtable
struct _jc_soot_dava_internal_SET_SETCycleNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETCycleNode$vmethods	soot_dava_internal_SET_SETCycleNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETCycleNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETCycleNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETCycleNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETCycleNode$refs {
    _jc_soot_dava_internal_SET_SETCycleNode$sub_refs	soot_dava_internal_SET_SETCycleNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETCycleNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs	soot_dava_internal_SET_SETCycleNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETCycleNode$object {
	_jc_soot_dava_internal_SET_SETCycleNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETCycleNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETCycleNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETCycleNode$vtype _jc_soot_dava_internal_SET_SETCycleNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETCycleNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETCycleNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETCycleNode_H_ */
